summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorMichael Brown2005-06-02 12:15:40 +0200
committerMichael Brown2005-06-02 12:15:40 +0200
commit7d8adc25bc6939667339054b9315c8f00ba35946 (patch)
tree0c525dab2941cd776abac06c21eececcf731302e /src/include
parentAlways include code for sending multicast packets. (diff)
downloadipxe-7d8adc25bc6939667339054b9315c8f00ba35946.tar.gz
ipxe-7d8adc25bc6939667339054b9315c8f00ba35946.tar.xz
ipxe-7d8adc25bc6939667339054b9315c8f00ba35946.zip
In multicast operation, the client still has a unicast local port.
Diffstat (limited to 'src/include')
-rw-r--r--src/include/tftp.h19
1 files changed, 9 insertions, 10 deletions
diff --git a/src/include/tftp.h b/src/include/tftp.h
index 5922a3292..2a086eb2b 100644
--- a/src/include/tftp.h
+++ b/src/include/tftp.h
@@ -100,19 +100,18 @@ struct tftp_state {
* will be sent, and to which ACK packets should be sent.
*/
struct sockaddr_in server;
/** TFTP client address
*
- * The IP address, if any, is the multicast address to which
- * data packets will be sent. The client will always send
- * packets from its own IP address.
+ * This is the UDP port from which the open request will be
+ * sent, and to which any unicast data packets will be sent.
+ */
+ in_port_t lport;
+ /** TFTP multicast address
*
- * The UDP port is the port from which the open request will
- * be sent, and to which data packets will be sent. (Due to
- * the "design" of the MTFTP protocol, the master client will
- * receive its first data packet as unicast, and subsequent
- * packets as multicast.)
+ * This is the IP address and UDP port to which multicast data
+ * packets, if any, will be sent.
*/
- struct sockaddr_in client;
+ struct sockaddr_in multicast;
/** Master client
*
* This will be true if the client is the master client for a
@@ -100,19 +100,18 @@ struct tftp_state {
*/
struct sockaddr_in server;
- /** TFTP client address
+ /** TFTP client port
*